<{{ htmlElement | default:'div' }} class="tna-container {{ classes }}{% if maxWidth %} tna-container--max{% endif %}{% if noPadding %} tna-container--no-padding{% endif %}" {% for attribute, value in attributes.items %} {{ attribute }}="{{ value }}"{% endfor %}>
{% for item in columns %}
    <{{ item.htmlElement | default:'div' }} class="tna-column {{ item.classes }}{% if item.width %}{% if item.width == 'full' %} tna-column--full{% else %} tna-column--width-{{ item.width }}{% endif %}{% endif %}{% if item.widthMedium %}{% if item.widthMedium == 'full' %} tna-column--full-medium{% else %} tna-column--width-{{ item.widthMedium }}-medium{% endif %}{% endif %}{% if item.widthSmall %}{% if item.widthSmall == 'full' %} tna-column--full-small{% else %} tna-column--width-{{ item.widthSmall }}-small{% endif %}{% endif %}{% if item.widthTiny %}{% if item.widthTiny == 'full' %} tna-column--full-tiny{% else %} tna-column--width-{{ item.widthTiny }}-tiny{% endif %}{% endif %}{% if item.flex %} tna-column--flex-{{ item.flex }}{% endif %}{% if item.flexMedium %} tna-column--flex-{{ item.flexMedium }}-medium{% endif %}{% if item.flexSmall %} tna-column--flex-{{ item.flexSmall }}-small{% endif %}{% if item.flexTiny %} tna-column--flex-{{ item.flexTiny }}-tiny{% endif %}{% if item.noPadding %} tna-column--noPadding{% endif %}" {% for attribute, value in item.attributes.items %} {{ attribute }}="{{ value }}"{% endfor %}>
        {{ item.html | safe }}
    </{{ item.htmlElement | default:'div' }}>
{% endfor %}
</{{ htmlElement | default:'div' }}>
