<a href="{{ href }}" class="tna-button{% if accent %} tna-button--accent{% endif %} {{ classes }}" role="button" {% if title %}title="{{ title }}"{% endif %} {% for attribute, value in attributes.items %} {{ attribute }}="{{ value }}"{% endfor %}>
    {{ text }}
</a>
