<div class="tna-sensitive-image {{ classes }}" data-module="tna-sensitive-image" style="--sensitive-image: url('{{ image.src }}'); --sensitive-image-width: {{ image.width }}; --sensitive-image-height: {{ image.height }}" {% for attribute, value in attributes.items %} {{ attribute }}="{{ value }}"{% endfor %}>
    <p class="tna-sensitive-image__warning">{{ warning }}</p>
    <details class="tna-sensitive-image__details">
        <summary class="tna-sensitive-image__show" data-action="{{ action }}">{{ action }}</summary>
        <div class="tna-sensitive-image__container">
            <img src="{{ image.src }}" alt="{{ image.alt }}" class="tna-sensitive-image__image" />
        </div>
    </details>
</div>
