<a href="#{{ href | default:'main-content' }}" class="tna-skip-link {{ classes }}" data-module="tna-skip-link" {% for attribute, value in attributes.items %} {{ attribute }}="{{ value }}"{% endfor %}>
  {{ text | default:'Skip to main content' }}
</a>
