<div class="tna-cookie-banner {{ classes }}" role="region" aria-label="Cookie usage" data-module="tna-cookie-banner" data-policies="{{ policies | default:'usage,settings' }}" data-preferenceskey="{{ cookiesPreferencesSetKey | default:'cookies_preferences_set' }}"{% if loadScriptsOnAccept %} data-acceptscripts="{{ loadScriptsOnAccept }}"{% endif %}{% for attribute, value in attributes.items %} {{ attribute }}="{{ value }}"{% endfor %} hidden>
  <div class="tna-container">
    <div class="tna-column tna-column--full tna-cookie-banner__message tna-cookie-banner__message--prompt">
      <h2 class="tna-heading-m">This website uses cookies</h2>
      <p>We use some essential cookies to make this service work.</p>
      <p>We'd also like to use analytics cookies so we can understand how you use the service and make improvements.</p>
      <div class="tna-button-group">
        <button class="tna-button" value="accept">Accept cookies</button>
        <button class="tna-button " value="reject">Reject cookies</button>
        <a href="{{ cookiesUrl }}" class="tna-button tna-button--plain" role="button">Set cookie preferences</a>
      </div>
    </div>
    <div class="tna-column tna-column--full tna-cookie-banner__message tna-cookie-banner__message--accepted" tabindex="0" hidden>
      <p>
        You have accepted optional cookies. You can change your cookie settings on the <a href="{{ cookiesUrl }}">Cookies page</a>.
      </p>
      <div class="tna-button-group">
        <button class="tna-button" value="close">Close this message</button>
      </div>
    </div>
    <div class="tna-column tna-column--full tna-cookie-banner__message tna-cookie-banner__message--rejected" tabindex="0" hidden>
      <p>
        You have rejected optional cookies. You can change your cookie settings on the <a href="{{ cookiesUrl }}">Cookies page</a>.
      </p>
      <div class="tna-button-group">
        <button class="tna-button" value="close">Close this message</button>
      </div>
    </div>
  </div>
</div>
